@@ -1,15 +1,17 @@
 # encoding=UTF-8
 
-# Copyright © 2008-2016 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2008-2017 Jakub Wilk <jwilk@jwilk.net>
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 dated June, 1991.
+# This file is part of ocrodjvu.
 #
-# This program is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# General Public License for more details.
+# ocrodjvu is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 2 as
+# published by the Free Software Foundation.
+#
+# ocrodjvu is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+# for more details.
 
 from __future__ import print_function
 
@@ -24,6 +26,7 @@ import sys
 import threading
 import traceback
 
+from .. import cli
 from .. import engines
 from .. import errors
 from .. import ipc
@@ -49,7 +52,7 @@ class Saver(object):
 
     @utils.not_overridden
     def save(self, document, pages, djvu_path, sed_file):
-        raise NotImplementedError('Cannot save results in this format')  # <no-coverage>
+        raise NotImplementedError('Cannot save results in this format')  # no coverage
 
 class BundledSaver(Saver):
 
@@ -148,7 +151,7 @@ def expand_template(template, pageno, pageid):
         d[var] = d[base_var] + offset
     return formatter.vformat(template, (), d)
 
-class ArgumentParser(argparse.ArgumentParser):
+class ArgumentParser(cli.ArgumentParser):
 
     savers = BundledSaver, IndirectSaver, ScriptSaver, InPlaceSaver, DryRunSaver
     engines = list(engines.get_engines())
@@ -168,9 +171,8 @@ class ArgumentParser(argparse.ArgumentParser):
 
     def __init__(self):
         usage = '%(prog)s [options] FILE'
-        version = '%(prog)s ' + __version__
-        argparse.ArgumentParser.__init__(self, usage=usage)
-        self.add_argument('-v', '--version', action='version', version=version, help='show version information and exit')
+        cli.ArgumentParser.__init__(self, usage=usage)
+        self.add_argument('--version', action=version.VersionAction)
         group = self.add_argument_group(title='options controlling output')
         for saver_type in self.savers:
             options = saver_type.options
@@ -263,7 +265,7 @@ class ArgumentParser(argparse.ArgumentParser):
                 namespace.saver = None
 
     def parse_args(self, args=None, namespace=None):
-        options = argparse.ArgumentParser.parse_args(self, args, namespace)
+        options = cli.ArgumentParser.parse_args(self, args, namespace)
         options.details = self._details_map[options.details]
         options.render_layers = self._render_map[options.render_layers]
         options.resume_on_error = options.on_error == 'resume'
